
# Type: range


defines the type of the object of the slot.  Given the following slot definition
  S1:
    domain: C1
    range:  C2
the declaration
  X:
    S1: Y

implicitly asserts Y is an instance of C2

URI: [meta:range](https://w3id.org/biolink/biolinkml/meta/range)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Element](Element.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
